@@ -7,6 +7,6 @@ extern crate bitflags;
 #[macro_use]
 mod macros;
 
-mod auto;
+pub mod auto;
 pub use auto::*;
 
